============
Installation
============

Source Code
===========

All the code is in my repository on GitHub_.

Requirements
============

* Python_ 3.6 or newer
* NumPy_ (base N-dimensional array package)
* SciPy_ (fundamental algorithms for scientific computing in Python)

Other recommended packages:

* Matplotlib_ (for plotting)
* PySimpleGUI_ (for the GUI)

Installation using pip
======================

The simplest way to install Debye Tools is to use pip_ which will automatically get
the source code from PyPI_::

    $ pip install --upgrade debyetools

.. _Python: https://www.python.org/
.. _NumPy: https://docs.scipy.org/doc/numpy/reference/
.. _PyPI: https://pypi.org/project/ase
.. _SciPy: https://scipy.org
.. _PIP: https://pip.pypa.io/en/stable/
.. _Matplotlib: https://matplotlib.org/
.. _PySimpleGUI: https://pysimplegui.readthedocs.io/en/latest/

.. _GitHub: https://github.com/jjofres/debyetools
